==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebGroupByKeyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByKeyDescription } from "./WebGroupByKeyDescription";
/**
 * @hidden
 */
var WebGroupByKeyDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGroupByKeyDescriptionMetadata, _super);
    function WebGroupByKeyDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupByKeyDescriptionMetadata.b = function (a) {
        if (WebGroupByKeyDescriptionMetadata.a == null) {
            WebGroupByKeyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupByKeyDescriptionMetadata.c(WebGroupByKeyDescriptionMetadata.a);
        }
        if (a.j(WebGroupByKeyDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGroupByKeyDescriptionMetadata.a);
    };
    WebGroupByKeyDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GroupByKey");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("FieldName", "String");
        a.item("Value", "Unknown");
    };
    WebGroupByKeyDescriptionMetadata.d = function (a) {
        WebGroupByKeyDescriptionMetadata.b(a);
        a.aa("WebGroupByKey", function () { return new WebGroupByKeyDescription(); });
        a.z("WebGroupByKey", WebGroupByKeyDescriptionMetadata.a);
    };
    WebGroupByKeyDescriptionMetadata.$t = markType(WebGroupByKeyDescriptionMetadata, 'WebGroupByKeyDescriptionMetadata');
    WebGroupByKeyDescriptionMetadata.a = null;
    return WebGroupByKeyDescriptionMetadata;
}(Base));
export { WebGroupByKeyDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebGroupByKeyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByKeyDescription } from "./WebGroupByKeyDescription";
/**
 * @hidden
 */
var WebGroupByKeyDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGroupByKeyDescriptionMetadata, _super);
    function WebGroupByKeyDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupByKeyDescriptionMetadata.b = function (a) {
        if (WebGroupByKeyDescriptionMetadata.a == null) {
            WebGroupByKeyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupByKeyDescriptionMetadata.c(WebGroupByKeyDescriptionMetadata.a);
        }
        if (a.k(WebGroupByKeyDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGroupByKeyDescriptionMetadata.a);
    };
    WebGroupByKeyDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GroupByKey");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("FieldName", "String");
        a.item("Value", "Unknown");
    };
    WebGroupByKeyDescriptionMetadata.d = function (a) {
        WebGroupByKeyDescriptionMetadata.b(a);
        a.ac("WebGroupByKey", function () { return new WebGroupByKeyDescription(); });
        a.ab("WebGroupByKey", WebGroupByKeyDescriptionMetadata.a);
    };
    WebGroupByKeyDescriptionMetadata.$t = markType(WebGroupByKeyDescriptionMetadata, 'WebGroupByKeyDescriptionMetadata');
    WebGroupByKeyDescriptionMetadata.a = null;
    return WebGroupByKeyDescriptionMetadata;
}(Base));
export { WebGroupByKeyDescriptionMetadata };
